@@ -124,6 +124,10 @@ gnome_ditem_edit_class_init (GnomeDItemEditClass *klass)
         object_class = (GtkObjectClass*) klass;
         gobject_class = (GObjectClass*) klass;
 
+        bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+        textdomain (GETTEXT_PACKAGE);
+
         ditem_edit_signals[CHANGED] =
                 g_signal_new ("changed",
                                 G_TYPE_FROM_CLASS (object_class),
@@ -1026,18 +1030,14 @@ gnome_ditem_edit_sync_display (GnomeDItemEdit *dee)
 static const char *
 get_language (void)
 {
-	/* there is some include header problem and we can't include the
-	   gnome i18n header or some such */
-	extern const GList *gnome_i18n_get_language_list (const char *category);
+	const char * const *languages;
+        int                 i;
 
-	const GList *list;
-	const GList *l;
+        languages = g_get_language_names ();
 
-	list = gnome_i18n_get_language_list ("LC_MESSAGES");
-
-	for (l = list; l; l = l->next)
-		if (!strchr (l->data, '.'))
-			return (char *) l->data;
+	for (i = 0; languages[i] != NULL; i++)
+		if (!strchr (languages[i], '.'))
+			return languages[i];
 
 	return NULL;
 }
